input.hostname,select {
    font-size:			13.3333px !important;
    text-transform:		none !important;

    -moz-box-shadow: 		2px 2px 2px #000;
    -webkit-box-shadow: 	2px 2px 2px #000;
    box-shadow: 		2px 2px 2px #000;
*/
}

input, select, button, table {
    font-family:		"Times New Roman", Times, serif !important;
    font-size:			13.3333px !important;
}

#tabs {
    padding:			0;
}
/*
.ui-tabs-nav {
    position:			fixed;
    width:			100%;
}
*/
html,body {
    margin:			0;
    padding:			0;
    height:			100%;
}

button {
    width:			400px;
    height:			50px;
    font-size:			medium;
}

#submit_button {
    padding:			30px;
    outline: 			5px solid #778899;
    background-color:		white;
    position:			fixed;
    bottom:			0;
    left:			0;
    width:			100%;
}

table {
    border-spacing: 		0;
    margin-left:		auto;
    margin-right:		auto;
    -moz-border-radius: 	15px 15px 15px 15px;
    -webkit-border-radius: 	15px 15px 15px 15px;
    border-radius: 		15px 15px 15px 15px;
    overflow: 			hidden;
}

.hidden {
    bottom:			0;
}

th,td {
    padding:			15px;
    white-space:		nowrap;
}

.center {
    text-align:			center;
}

th {
    background-color:		blue;
    color:			white;
    text-transform:		uppercase;

    -moz-text-shadow: 		2px 2px 2px #000;
    -webkit-text-shadow: 	2px 2px 2px #000;
    text-shadow: 		2px 2px 2px #000;
*/
}

td:first-child, th:first-child {
    border-left: 		none;
}

th:first-child {
    -moz-border-radius: 	15px 0 0 0;
    -webkit-border-radius: 	15px 0 0 0;
    border-radius: 		15px 0 0 0;
}

th:last-child {
    -moz-border-radius: 	0 15px 0 0;
    -webkit-border-radius: 	0 15px 0 0;
    border-radius: 		0 15px 0 0;
}

th:only-child {
    -moz-border-radius: 	15px 15px 0 0;
    -webkit-border-radius: 	15px 15px 0 0;
    border-radius: 		15px 15px 0 0;
}

tr:first-child {
    -moz-border-radius: 	15px 15px 0 0;
    -webkit-border-radius: 	15px 15px 0 0;
    border-radius: 		15px 15px 0 0;
}

tr:last-child {
    -moz-border-radius: 	0 0 15px 15px;
    -webkit-border-radius: 	0 0 15px 15px;
    border-radius: 		0 0 15px 15px;

}
/*
tr:last-child td:nth-child(3) {
    -moz-border-radius: 	0 0 0 15px;
    -webkit-border-radius: 	0 0 0 15px;
    border-radius: 		0 0 0 15px;
}
*/
/*
tr:last-child td:last-child {
    -moz-border-radius: 	0 0 15px 0;
    -webkit-border-radius: 	0 0 15px 0;
    border-radius: 		0 0 15px 0;
}
*/

table.data td:last-child {
    -moz-border-radius: 	0 0 0 0;
    -webkit-border-radius: 	0 0 0 0;
    border-radius: 		0 0 0 0;
}

table.data tr:last-child td:last-child {
    -moz-border-radius: 	0 0 15px 0;
    -webkit-border-radius: 	0 0 15px 0;
    border-radius: 		0 0 15px 0;
}

table tr {
    background:			rgba(255,255,255,0.5);
    opacity:			0.9 !important;
    filter:			alpha(opacity=90) !important;
}

table tr:nth-child(even) td {
    background:			rgba(204,255,255,0.5);
}

table#main {
    margin-top:			45px;
    margin-bottom:		140px;
}

.note {
    margin-top:			45px;
}

table#hist {
    margin-top:			25px;
}

table#main tr table.data tr td {
    background-color:		white;
}

table#main tr:nth-child(even) table.data tr td {
    background-color:		#CCFFFF;
}

html {
    background:			url('/static/mach_info/image/ebay.png') no-repeat center center fixed;
    -webkit-background-size: 	cover;
    -moz-background-size: 	cover;
    -o-background-size: 	cover;
    background-size: 		cover;
}

a#naming {
    color:			white !important;
    text-transform:		none !important;
}

a#naming:hover {
    color:			black !important;
}

.delete:hover {
    outline: 			5px solid black;
    outline-offset: 		5px;
}

.ui-widget-content {
    border:			0 !important;
    background:			scroll 50% 50% rgba(255,255,255,0) !important;
}

.ui-tabs-nav {
    position:			fixed;
    width:			100%;
    z-index:			1000;
}
