from mach_info.models import *
from django.contrib import admin

admin.site.register(Machine)
admin.site.register(NetInfo)
admin.site.register(HwModel)
admin.site.register(JobTracker)
admin.site.register(Os)
admin.site.register(Switch)
admin.site.register(Profile)
admin.site.register(Step)